
ruamel.yaml
===========

``ruamel.yaml`` is a YAML 1.2 loader/dumper package for Python.

* `Overview <http://yaml.readthedocs.org/en/latest/overview.html>`_
* `Installing <http://yaml.readthedocs.org/en/latest/install.html>`_
* `Details <http://yaml.readthedocs.org/en/latest/detail.html>`_
* `Examples <http://yaml.readthedocs.org/en/latest/example.html>`_
* `Differences with PyYAML <http://yaml.readthedocs.org/en/latest/pyyaml.html>`_

.. image:: https://readthedocs.org/projects/yaml/badge/?version=stable
   :target: https://yaml.readthedocs.org/en/stable

ChangeLog
=========

.. should insert NEXT: at the beginning of line for next key

0.14.11 (2017-05-01):
  - fix for issue 103 allowing implicit documents after document end marker line (``...``)
    in YAML 1.2

0.14.10 (2017-04-26):
  - fix problem with emitting using cyaml

0.14.9 (2017-04-22):
  - remove dependency on ``typing`` while still supporting ``mypy``
    (http://stackoverflow.com/a/43516781/1307905)
  - fix unclarity in doc that stated 2.6 is supported (reported by feetdust)

0.14.8 (2017-04-19):
  - fix Text not available on 3.5.0 and 3.5.1, now proactively setting version guards
    on all files (reported by `João Paulo Magalhães <https://bitbucket.org/jpmag/>`_)

0.14.7 (2017-04-18):
  - round trip of integers (decimal, octal, hex, binary) now preserve
    leading zero(s) padding and underscores. Underscores are presumed
    to be at regular distances (i.e. ``0o12_345_67`` dumps back as
    ``0o1_23_45_67`` as the space from the last digit to the
    underscore before that is the determining factor).

0.14.6 (2017-04-14):
  - binary, octal and hex integers are now preserved by default. This
    was a known deficiency. Working on this was prompted by the issue report (112)
    from devnoname120, as well as the additional experience with `.replace()`
    on `scalarstring` classes.
  - fix issues 114: cannot install on Buildozer (reported by mixmastamyk).
    Setting env. var ``RUAMEL_NO_PIP_INSTALL_CHECK`` will suppress ``pip``-check.

0.14.5 (2017-04-04):
  - fix issue 109: None not dumping correctly at top level (reported by Andrea Censi)
  - fix issue 110: .replace on Preserved/DoubleQuoted/SingleQuoted ScalarString
    would give back "normal" string (reported by sandres23)

0.14.4 (2017-03-31):
  - fix readme

0.14.3 (2017-03-31):
  - fix for 0o52 not being a string in YAML 1.1 (reported on
    `StackOverflow Q&A 43138503 <http://stackoverflow.com/a/43138503/1307905>`_ by
    `Frank D <http://stackoverflow.com/users/7796630/frank-d>`_)

0.14.2 (2017-03-23):
  - fix for old default pip on Ubuntu 14.04 (reported by Sébastien Maccagnoni-Munch)

0.14.1 (2017-03-22):
  - fix Text not available on 3.5.0 and 3.5.1 (reported by Charles Bouchard-Légaré)

0.14.0 (2017-03-21):
  - updates for mypy --strict
  - preparation for moving away from inheritance in Loader and Dumper, calls from e.g.
    the Representer to the Serializer.serialize() are now done via the attribute
    .serializer.serialize(). Usage of .serialize() outside of Serializer will be
    deprecated soon
  - some extra tests on main.py functions

0.13.14 (2017-02-12):
  - fix for issue 97: clipped block scalar followed by empty lines and comment
    would result in two CommentTokens of which the first was dropped.
    (reported by Colm O'Connor)

0.13.13 (2017-01-28):
  - fix for issue 96: prevent insertion of extra empty line if indented mapping entries
    are separated by an empty line (reported by Derrick Sawyer)

0.13.11 (2017-01-23):
  - allow ':' in flow style scalars if not followed by space. Also don't
    quote such scalar as this is no longer necessary.
  - add python 3.6 manylinux wheel to PyPI

0.13.10 (2017-01-22):
  - fix for issue 93, insert spurious blank line before single line comment
    between indented sequence elements (reported by Alex)

0.13.9 (2017-01-18):
  - fix for issue 92, wrong import name reported by the-corinthian

0.13.8 (2017-01-18):
  - fix for issue 91, when a compiler is unavailable reported by Maximilian Hils
  - fix for deepcopy issue with TimeStamps not preserving 'T', reported on
    `StackOverflow Q&A <http://stackoverflow.com/a/41577841/1307905>`_ by
    `Quuxplusone <http://stackoverflow.com/users/1424877/quuxplusone>`_


0.13.7 (2016-12-27):
  - fix for issue 85, constructor.py importing unicode_literals caused mypy to fail
    on 2.7 (reported by Peter Amstutz)

0.13.6 (2016-12-27):
  - fix for issue 83, collections.OrderedDict not representable by SafeRepresenter
    (reported by Frazer McLean)

0.13.5 (2016-12-25):
  - fix for issue 84, deepcopy not properly working (reported by Peter Amstutz)

0.13.4 (2016-12-05):
  - another fix for issue 82, change to non-global resolver data broke implicit type
    specification

0.13.3 (2016-12-05):
  - fix for issue 82, deepcopy not working (reported by code monk)

0.13.2 (2016-11-28):
  - fix for comments after empty (null) values  (reported by dsw2127 and cokelaer)

0.13.1 (2016-11-22):
  - optimisations on memory usage when loading YAML from large files (py3: -50%, py2: -85%)

0.13.0 (2016-11-20):
  - if ``load()`` or ``load_all()`` is called with only a single argument
    (stream or string)
    a UnsafeLoaderWarning will be issued once. If appropriate you can surpress this
    warning by filtering it. Explicitly supplying the ``Loader=ruamel.yaml.Loader``
    argument, will also prevent it from being issued. You should however consider
    using ``safe_load()``, ``safe_load_all()`` if your YAML input does not use tags.
  - allow adding comments before and after keys (based on
    `StackOveflow Q&A <http://stackoverflow.com/a/40705671/1307905>`_  by
    `msinn <http://stackoverflow.com/users/7185467/msinn>`_)

----

For older changes see the file
`CHANGES <https://bitbucket.org/ruamel/yaml/src/default/CHANGES>`_
